History
=======

1.0.1 (2025-12-11)
------------------

* Improve CI matrix and drop failing Python 3.7 job.
* Fix Sphinx configuration and RTD build (language and theme deps).
* Tidy stopwatch implementation for style (flake8) and clarity.

1.0.0 (2025-12-10)
------------------

* First stable release.
* Add unit tests, CI configuration, and timing bugfixes.

0.2.2 (2024-11-27)
------------------

* Fix precision setting not taking effect in some cases.
* Packaging and configuration updates.

0.2.1 (2024-11-27)
------------------

* Fix search behaviour when using string keys (strings being iterable).

0.2.0 (2024-11-27)
------------------

* Add a ``precision`` setting for timestamps.
* Add ``Stopwatch.get_ticks(...)`` helper to search ticks.
* Documentation updates and minor internal cleanups.

0.1.1 (2022-02-10)
------------------

* Fix PyPI upload issue due to history formatting.

0.1.0 (2022-02-10)
------------------

* Internal refactors and documentation improvements.

0.0.3 (2022-01-24)
------------------

* Replace ``namedtuple`` with ``dataclasses`` for ticks.
* Use ``time.perf_counter`` for timing.
* Miscellaneous bug fixes and improvements.

0.0.2 (2021-04-12)
------------------

* Minor fixes and documentation updates.

0.0.1 (2021-04-13)
------------------

* First release on PyPI.
